initialize method
Initializes backend resources that are independent of viewport size.
Implementation
@override
Future<void> initialize({bool debug = true}) async {
gpu.gpuContext.defaultColorFormat;
await _depthSorter.initialize();
}
Initializes backend resources that are independent of viewport size.
@override
Future<void> initialize({bool debug = true}) async {
gpu.gpuContext.defaultColorFormat;
await _depthSorter.initialize();
}