buildOutput abstract method
Builds the widget that displays the last rendered frame.
Implementation
Widget buildOutput(BuildContext context, {required Size logicalSize});
Builds the widget that displays the last rendered frame.
Widget buildOutput(BuildContext context, {required Size logicalSize});